# Tapioca sectigo_api_ssl

## Installation
```
pip install tapioca-sectigo_api_ssl
```

## Documentation
``` python
from tapioca_sectigo_api_ssl import Sectigo_api_ssl


api = Sectigo_api_ssl()

```

No more documentation needed.

- Learn how Tapioca works [here](http://tapioca-wrapper.readthedocs.org/en/stable/quickstart.html)
- Explore this package using iPython
- Have fun!
